@@ -20,7 +20,5 @@ pub use types::*;
 #[cfg(feature = "serialize")]
 pub use serialize::*;
 
-// swc re-exports
-pub use swc_common::comments::{Comment, CommentKind};
-pub use swc_common::{BytePos, Span, Spanned};
-pub use swc_ecmascript::parser::token::{Token, TokenAndSpan};
+#[cfg(test)]
+mod test_helpers;
